@@ -8,14 +8,14 @@
 #######################################################################
 
 import os
-from subprocess import check_output, CalledProcessError
+from subprocess import check_output, CalledProcessError, STDOUT
 from simpleloggerplus import simpleloggerplus as log
 from cryptdomainmgr.modules.common.cdmfilehelper import makeDir
 import time
 
 defaultConfig = {'keysize': 4096, 'extraflags': '', 'caa': {'url': 'letsencrypt.org', 'flag': '0', 'tag': 'issue'}}
 
-def prepare(certConfig, certState, statedir, domainList, domainAccessTable): 
+def prepare(certConfig, certState, statedir, domainList, domainAccessTable):
     if 'dehydrated' != certConfig['handler'].split('/')[0]:
         return
     if 0 == len(domainList):
@@ -57,29 +57,42 @@ def prepare(certConfig, certState, statedir, domainList, domainAccessTable):
     log.debug(args)
     certState.setOpStateRunning()
 
-    for i in range(10):
+    i = 0
+    while True:
         try:
-            rv = check_output(args, env=dict(os.environ, DOMAINACCESSTABLE=domainAccessTable))
-            log.info(rv)
+            log.info('Starting DNS-01 authentication')
+            rv = check_output(args, stderr=STDOUT, env=dict(os.environ, DOMAINACCESSTABLE=domainAccessTable, STATEDIR=statedir, WAITSEC="{}".format(3**i)))
+            log.info(rv.decode())
             break
         except CalledProcessError as e:
-            log.error(e.output)
-            time.sleep(1)
+            if 'ERROR: Lock file' in e.output.decode():
+                lockFilename = e.output.decode().split('ERROR: Lock file \'')[-1].split('\' present, aborting')[0]
+                log.warn('Lock file from imcomplete run found: {}'.format(lockFilename))
+                log.warn('  -> Removing')
+                os.remove(lockFilename)
+            if 'Incorrect TXT record' in e.output.decode():
+                log.info('  -> Invalid DNS-01 challenge, maybe due to DNS caching interval. Trying to wait longer!')
+                i += 1
+                log.info('  -> Will wait {} s to give challenge time to propagate DNS cache.'.format(3**i))
+            if 'NXDOMAIN' in e.output.decode():
+                log.info('  -> Missing DNS-01 challenge, maybe due to DNS caching interval. Trying to wait longer!')
+                i += 1
+                log.info('  -> Will wait {} s to give challenge time to propagate DNS cache.'.format(3**i))
             if 9 == i:
                 raise(e)
 
     res = []
     rv = rv.splitlines()
     for s, e in enumerate(rv):
-        if '---- DEPLOYMENTRESULT ----' == e[:len('---- DEPLOYMENTRESULT ----')]:
+        if '---- DEPLOYMENTRESULT ----' == e.decode()[:len('---- DEPLOYMENTRESULT ----')]:
             break
     for i, e in enumerate(rv[s+1:]):
-        if '---- END DEPLOYMENTRESULT ----' == e[:len('---- END DEPLOYMENTRESULT ----')]:
+        if '---- END DEPLOYMENTRESULT ----' == e.decode()[:len('---- END DEPLOYMENTRESULT ----')]:
             break
         res.append(e)
-    resDict = {e.split('=')[0].lower(): e.split('=')[1] for e in res}
+    resDict = {e.decode().split('=')[0].lower(): e.decode().split('=')[1] for e in res}
     resDict['san'] = list(domainList)
-    
+
     if 'running' == certState.opstate:
         certState.registerResult(resDict)
     certState.setOpStateDone()
