@@ -11,7 +11,6 @@ import os
 from subprocess import check_output, CalledProcessError
 from simpleloggerplus import simpleloggerplus as log
 from jinja2 import Template
-from parse import parse
 import time
 from cryptdomainmgr.modules.common.cdmfilehelper import makeDir
 
@@ -28,7 +27,7 @@ def prepare(dkimConfig, dkimState, statedir):
         dkimState.setOpStateDone()
 
 def rollover(dkimConfig, dkimState):
-    if 'rspamd' == dkimConfig['handler'].split('/')[0]: 
+    if 'rspamd' == dkimConfig['handler'].split('/')[0]:
         log.info('using new dkim key, moving new config file')
         copyDKIM(dkimConfig, dkimState)
         copyConf(dkimConfig, dkimState)
@@ -42,23 +41,37 @@ def copyDKIM(dkimConfig, dkimState):
     src = dkimState.result['keyfile']
     dest = os.path.join(dkimConfig['keylocation'], dkimConfig['keyname'])
     log.info('  {} -> {}'.format(src, dest))
+    try:
+        rv = check_output(('mkdir', '-p', os.path.dirname(str(dest))))
+    except CalledProcessError as e:
+        log.error("Failed to create directory path for {}".format(str(dest)))
     try:
         rv = check_output(('cp', '-rfLT', str(src), str(dest)))
+    except CalledProcessError as e:
+        log.error("Failed to copy file")
+        log.error("  {} -> {}".format(str(src), str(dest)))
+    try:
         rv = check_output(('chown', '_rspamd:_rspamd', str(dest)))
     except CalledProcessError as e:
-        log.error(e.output)
-        raise(e)
+        log.error("Failed to change ownership of {}".format(str(dest)))
 
 def copyConf(dkimConfig, dkimState):
     src = dkimState.result['signingconftemporaryfile']
     dest = dkimConfig['signingconfdestinationfile']
     log.info('  {} -> {}'.format(src, dest))
+    try:
+        rv = check_output(('mkdir', '-p', os.path.dirname(str(dest))))
+    except CalledProcessError as e:
+        log.error("Failed to create directory path for {}".format(str(dest)))
     try:
         rv = check_output(('cp', '-rfLT', str(src), str(dest)))
+    except CalledProcessError as e:
+        log.error("Failed to copy file")
+        log.error("  {} -> {}".format(str(src), str(dest)))
+    try:
         rv = check_output(('chown', '_rspamd:_rspamd', str(dest)))
     except CalledProcessError as e:
-        log.error(e.output)
-        raise(e)
+        log.error("Failed to change ownership of {}".format(str(dest)))
 
 def createSelector(keybasename):
     return str(keybasename) + '_{:10d}'.format(int(time.time()))
@@ -74,6 +87,11 @@ def createDKIM(keysize, destination):
     k = keyTxt.split('k=')[1].split(';')[0]
     pL = keyTxt.split('p=')[1].split('\"')
     p = "".join([e for e in pL if ")" not in e and "\n" not in e])
+    print(type(p))
+    print(p)
+    p = p.replace("\\n", "").replace("\\t", "")
+    print(type(p))
+    print(p)
     return {'v': v, 'k': k, 'p': p, 'keyfile': str(destination)}
 
 
