@@ -11,6 +11,8 @@ from simpleloggerplus import simpleloggerplus as log
 from subprocess import check_output, CalledProcessError
 from cryptdomainmgr.modules.common.cdmstatehelper import isReady
 
+defaultConfig={'depends': 'dkim'}
+
 def prepare(serviceConfig, serviceState, state):
     serviceState.setOpStateDone()
 
@@ -21,11 +23,7 @@ def rollover(serviceConfig, serviceState, state):
     serviceState.setOpStateRunning()
     log.info('  -> Rspamd reload')
     try:
-        rv = check_output(('systemctl', 'start', 'rspamd'))
-        #rv = check_output(('systemctl', 'reload', 'rspamd')) # this is not working with rspamd
-        #rv = check_output(('rspamadm', 'control', 'reload'))
-        # only restart works - bug in rspamd
-        rv = check_output(('systemctl', 'restart', 'rspamd'))
+        rv = check_output(('systemctl', 'reload', 'rspamd')) # this is now working with newer version of rspamd
     except CalledProcessError as e:
         log.error(e.output)
         raise(e)
